@@ -16,3 +16,14 @@ test_that("works", {
   expect_equal(out[, 1], paste0("item_", c(1, 1, 2, 4)))
   expect_equal(out[, 2], paste0("item_", c(2, 3, 3, 6)))
 })
+
+
+test_that("Github issue #1", {
+  inclDF <- data.frame(ID = paste0("item_", 1:6),
+                       stem = c(rep("stim_1", 3), "stim_3", "stim_3", "stim_3"),
+                       stringsAsFactors = FALSE)
+
+  out <- stemInclusionTuples(inclDF, idCol = "ID", stemCol = "stem")
+  expect_equal(out[, 1], paste0("item_", c(1, 1, 2, 4, 4, 5)))
+  expect_equal(out[, 2], paste0("item_", c(2, 3, 3, 5, 6, 6)))
+})
